
h1 {
  text-shadow: 0 1px 2px rgba(0,0,0,0.3);
}
h2 {
  border-bottom: 1px solid #ccc;
}

dl dt {
  font-weight: bold;
  font-style: italic;
}

li {
  margin: 0.5em 0;
}

pre {
  border: 1px solid #ccc;
  border-radius: 3px;
  box-shadow: 0 1px 3px rgba(0,0,0,0.3);
  padding: 0.6em 1em;
  background-color: #eee;
}

table tr td {
  border: 1px solid #ccc;
  padding: 0.4em 0.8em;
  margin: 0;
}

table tr:nth-child(2n) {
  background-color:#f5f5f5;
}